# -*- coding: utf-8 -*-
class Corpus:
    """Corpus is fundamental resource of NLP
    """
    def __init__(self):
        print("Corpus is fundamental resource of NLP")

    def load(self, folder):
        pass

    def save(self, folder):
        pass
